'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsxRuntime = require('react/jsx-runtime');
var core = require('@stitches/core');
var lodash = require('lodash');
var react = require('react');
var index = require('../../common/lib/Localization/index.js');
var constants = require('../../constants.js');
var MagicLink = require('./interfaces/MagicLink.js');
var SocialAuth = require('./interfaces/SocialAuth.js');
var EmailAuth = require('./interfaces/EmailAuth.js');
var ForgottenPassword = require('./interfaces/ForgottenPassword.js');
var UpdatePassword = require('./interfaces/UpdatePassword.js');
var UserContext = require('./UserContext.js');

function Auth(_ref) {
  let {
    supabaseClient,
    socialLayout = 'vertical',
    providers,
    view = 'sign_in',
    redirectTo,
    onlyThirdPartyProviders = false,
    magicLink = false,
    appearance,
    theme = 'default',
    localization = {
      lang: 'en'
    }
  } = _ref;

  /**
   * Localization support
   */
  var _a, _b, _c, _d, _e;

  const i18n = lodash.merge(index[(_a = localization.lang) !== null && _a !== void 0 ? _a : 'en'], (_b = localization.variables) !== null && _b !== void 0 ? _b : {}); // const themes = Object.values(appearance.themeFile ?? {}).map((theme) => {
  //   // return
  // })

  const [authView, setAuthView] = react.useState(view);
  const [defaultEmail, setDefaultEmail] = react.useState('');
  const [defaultPassword, setDefaultPassword] = react.useState('');
  /**
   * Simple boolean to detect if authView 'sign_in' or 'sign_up' is used
   *
   * @returns boolean
   */

  const SignView = authView === 'sign_in' || authView === 'sign_up';
  /**
   * Create default theme
   *
   * createStitches()
   * https://stitches.dev/docs/api#theme
   *
   * to add a new theme use  createTheme({})
   * https://stitches.dev/docs/api#theme
   */

  core.createStitches({
    theme: lodash.merge((_c = appearance === null || appearance === void 0 ? void 0 : appearance.theme) === null || _c === void 0 ? void 0 : _c.default, (_e = (_d = appearance === null || appearance === void 0 ? void 0 : appearance.variables) === null || _d === void 0 ? void 0 : _d.default) !== null && _e !== void 0 ? _e : {})
  });
  /**
   * Wraps around all auth components
   * renders the social auth providers if SignView is true
   *
   * also handles the theme override
   *
   * @param children
   * @returns React.ReactNode
   */

  const Container = _ref2 => {
    let {
      children
    } = _ref2;

    var _a, _b;

    return jsxRuntime.jsxs("div", Object.assign({
      className: theme !== 'default' ? core.createTheme(lodash.merge( // @ts-ignore
      appearance === null || appearance === void 0 ? void 0 : appearance.theme[theme], (_b = (_a = appearance === null || appearance === void 0 ? void 0 : appearance.variables) === null || _a === void 0 ? void 0 : _a[theme]) !== null && _b !== void 0 ? _b : {})) : ''
    }, {
      children: [SignView && jsxRuntime.jsx(SocialAuth.SocialAuth, {
        appearance: appearance,
        supabaseClient: supabaseClient,
        providers: providers,
        socialLayout: socialLayout,
        redirectTo: redirectTo,
        onlyThirdPartyProviders: onlyThirdPartyProviders,
        i18n: i18n,
        view: authView
      }), !onlyThirdPartyProviders && children]
    }));
  };

  react.useEffect(() => {
    /**
     * Overrides the authview if it is changed externally
     */
    setAuthView(view);
  }, [view]);
  const emailProp = {
    supabaseClient,
    setAuthView,
    defaultEmail,
    defaultPassword,
    setDefaultEmail,
    setDefaultPassword,
    redirectTo,
    magicLink,
    i18n
  };
  /**
   * View handler, displays the correct Auth view
   * all views are wrapped in <Container/>
   */

  switch (authView) {
    case constants.VIEWS.SIGN_IN:
      return jsxRuntime.jsx(Container, {
        children: jsxRuntime.jsx(EmailAuth.EmailAuth, Object.assign({}, emailProp, {
          authView: "sign_in",
          id: "auth-sign-in"
        }))
      });

    case constants.VIEWS.SIGN_UP:
      return jsxRuntime.jsx(Container, {
        children: jsxRuntime.jsx(EmailAuth.EmailAuth, {
          appearance: appearance,
          supabaseClient: supabaseClient,
          // @ts-expect-error
          authView: authView,
          setAuthView: setAuthView,
          defaultEmail: defaultEmail,
          defaultPassword: defaultPassword,
          setDefaultEmail: setDefaultEmail,
          setDefaultPassword: setDefaultPassword,
          redirectTo: redirectTo,
          magicLink: magicLink,
          i18n: i18n
        })
      });

    case constants.VIEWS.FORGOTTEN_PASSWORD:
      return jsxRuntime.jsx(Container, {
        children: jsxRuntime.jsx(ForgottenPassword.ForgottenPassword, {
          appearance: appearance,
          supabaseClient: supabaseClient,
          setAuthView: setAuthView,
          redirectTo: redirectTo,
          i18n: i18n
        })
      });

    case constants.VIEWS.MAGIC_LINK:
      return jsxRuntime.jsx(Container, {
        children: jsxRuntime.jsx(MagicLink.MagicLink, {
          appearance: appearance,
          supabaseClient: supabaseClient,
          setAuthView: setAuthView,
          redirectTo: redirectTo,
          i18n: i18n
        })
      });

    case constants.VIEWS.UPDATE_PASSWORD:
      return jsxRuntime.jsx(Container, {
        children: jsxRuntime.jsx(UpdatePassword.UpdatePassword, {
          appearance: appearance,
          supabaseClient: supabaseClient,
          i18n: i18n
        })
      });

    default:
      return null;
  }
}

Auth.ForgottenPassword = ForgottenPassword.ForgottenPassword;
Auth.UpdatePassword = UpdatePassword.UpdatePassword;
Auth.MagicLink = MagicLink.MagicLink;
Auth.UserContextProvider = UserContext.UserContextProvider;
Auth.useUser = UserContext.useUser;

exports["default"] = Auth;
